@@ -28,11 +28,12 @@ class APIGatewayRouteArn:
         self.api_id = api_id
         self.stage = stage
         self.http_method = http_method
-        self.resource = resource
+        # Remove matching "/" from `resource`.
+        self.resource = resource.lstrip("/")
 
     @property
     def arn(self) -> str:
-        """Build an arn from it's parts
+        """Build an arn from its parts
         eg: arn:aws:execute-api:us-east-1:123456789012:abcdef123/test/GET/request"""
         return (
             f"arn:{self.partition}:execute-api:{self.region}:{self.aws_account_id}:{self.api_id}/{self.stage}/"
@@ -168,7 +169,7 @@ class APIGatewayAuthorizerRequestEvent(DictWrapper):
         default_value: str, optional
             Default value if no value was found by name
         case_sensitive: bool
-            Whether to use a case sensitive look up
+            Whether to use a case-sensitive look up
         Returns
         -------
         str, optional
@@ -270,7 +271,7 @@ class APIGatewayAuthorizerEventV2(DictWrapper):
         default_value: str, optional
             Default value if no value was found by name
         case_sensitive: bool
-            Whether to use a case sensitive look up
+            Whether to use a case-sensitive look up
         Returns
         -------
         str, optional
@@ -355,7 +356,7 @@ class APIGatewayAuthorizerResponse:
     - https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-lambda-authorizer-output.html
     """
 
-    path_regex = r"^[/.a-zA-Z0-9-\*]+$"
+    path_regex = r"^[/.a-zA-Z0-9-_\*]+$"
     """The regular expression used to validate resource paths for the policy"""
 
     def __init__(
@@ -440,9 +441,6 @@ class APIGatewayAuthorizerResponse:
         if not self._resource_pattern.match(resource):
             raise ValueError(f"Invalid resource path: {resource}. Path should match {self.path_regex}")
 
-        if resource[:1] == "/":
-            resource = resource[1:]
-
         resource_arn = APIGatewayRouteArn(
             self.region, self.aws_account_id, self.api_id, self.stage, http_method, resource
         ).arn
