@@ -1,7 +1,9 @@
-from typing import Dict
+from typing import Dict, Union
 
 from pydantic import BaseModel
 
+from aws_lambda_powertools.utilities.parser.types import Model
+
 
 class AlbRequestContextData(BaseModel):
     targetGroupArn: str
@@ -14,7 +16,7 @@ class AlbRequestContext(BaseModel):
 class AlbModel(BaseModel):
     httpMethod: str
     path: str
-    body: str
+    body: Union[str, Model]
     isBase64Encoded: bool
     headers: Dict[str, str]
     queryStringParameters: Dict[str, str]
